<?php

//--------------------------------------
//  Methods
//--------------------------------------

	function getXmlKeyValue($value, $key)
	{
		if (strpos($value, "<".$key.">") < 0 || strpos($value, "</".$key.">") < 0) return "";
		return substr(substr($value, 0, strpos($value, "</".$key.">")), strpos($value, "<".$key.">") + strlen($key) + 2);
	}

//--------------------------------------
//  MSSQL Database
//--------------------------------------

	function parseSqlConnectionString($connectionString)
	{
		class connectionInfo {
			var $host;
			var $database;
			var $userId;
			var $password;
		}

		$object = new connectionInfo;
		$parameters = split(";", $connectionString);
		foreach($parameters as $parameter)
		{
			$parts = split("=", $parameter);
			$name = $parts[0];
			$value = $parts[1];

			if (isset($value))
			{
				switch (strtolower($name))
				{
					case "data source":
					case "server":
						$object->host = $value;
						break;

					case "database":
					case "initial catalog":
						$object->database = $value;
						break;

					case "user id":
						$object->userId = $value;
						break;

					case "password":
						$object->password = $value;
						break;
				}
			}
		}

		return $object;
	}

	function convertSqlType($type)
	{
		switch (strtolower($type))
		{
			case "numeric":
			case "int":
				return "System.Int64";

			case "blob":
			case "bit":
			case "char":
			case "image":
			case "text":
				return "System.String";

			case "datetime":
				return "System.DateTime";

			case "real":
			case "money":
				return "System.Decimal";
		}

		return $type;
	}

	function getSqlDatabaseColumns($host, $database, $userId, $password, $query)
	{
		$link = mssql_connect($host, $userId, $password) or die("ServerError:Could not connect to host.");
		mssql_select_db($database, $link) or die("ServerError:Could not find database.");

		$result = mssql_query($query, $link) or die("ServerError:Data not found.");

		$xml_output = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
		$xml_output .= "<Tables>\n";

		$i = 0;
		while ($column = mssql_fetch_field($result))
		{
			if ($i == 0) $xml_output .= "  <Table name='".$column->table."'>\n";
			$xml_output .= "    <Column name='".$column->name."' type='".convertSqlType($column->type)."' />\n";
			$i++;
		}
		$xml_output .= "  </Table>\n";
		$xml_output .= "</Tables>";

		mssql_free_result($result);
		mssql_close($link);

		return $xml_output;
	}

	function getDataFromSqlDatabase($host, $database, $userId, $password, $query)
	{
		$link = mssql_connect($host, $userId, $password) or die("ServerError:Could not connect to host.");
		mssql_select_db($database, $link) or die("ServerError:Could not find database.");

		$result = mssql_query($query, $link) or die("ServerError:Data not found.");

		$xml_output = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
		$xml_output .= "<Database>\n";

		$i = 0;
		while ($column = mssql_fetch_field($result))
		{
			$columns[$i] = $column->name;
			$tablename = $column->table;
			$i++;
		}

		while ($row = mssql_fetch_assoc($result))
		{
			$xml_output .= "  <".$tablename.">\n";
			foreach($columns as $column)
			{
				$value = $row[$column];
				$value = str_replace("&", "&amp;", $value);
				$value = str_replace("<", "&lt;", $value);
				$value = str_replace(">", "&gt;", $value);

				$xml_output .= "    <".$column.">".$value."</".$column.">\n";
			}
			$xml_output .= "  </".$tablename.">\n";
		}

		mssql_free_result($result);
		mssql_close($link);

		$xml_output .= "</Database>\n";
		return $xml_output;
	}

//--------------------------------------
//  MySql Database
//--------------------------------------

	function parseMySqlConnectionString($connectionString)
	{
		class connectionInfo {
			var $host;
			var $port = "3306";
			var $database;
			var $userId;
			var $password;
		}

		$object = new connectionInfo;
		$parameters = split(";", $connectionString);
		foreach($parameters as $parameter)
		{
			$parts = split("=", $parameter);
			$name = $parts[0];
			$value = $parts[1];

			if (isset($value))
			{
				switch (strtolower($name))
				{
					case "server":
					case "host":
					case "location":
						$object->host = $value;
						break;

					case "port":
						$object->port = $value;
						break;

					case "database":
					case "data source":
						$object->database = $value;
						break;

					case "uid":
					case "user id":
					case "user":
						$object->userId = $value;
						break;

					case "pwd":
					case "password":
						$object->password = $value;
						break;
				}
			}
		}

		return $object;
	}

	function convertMySqlType($type)
	{
		switch (strtolower($type))
		{
			case "string":
			case "blob":
				return "System.String";

			case "int":
				return "System.Int32";

			case "real":
				return "System.Decimal";

			case "date":
			case "time":
			case "datetime":
				return "System.DateTime";
		}

		return $type;
	}

	function getMySqlDatabaseColumns($host, $port, $database, $userId, $password, $query)
	{
		$link = mysql_connect($host.":".$port, $userId, $password) or die("ServerError:Could not connect to host.");
		mysql_select_db($database, $link) or die("ServerError:Could not find database.");

		$result = mysql_query($query, $link) or die("ServerError:Data not found.");

		$xml_output = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
		$xml_output .= "<Tables>\n";

		$i = 0;
		while ($column = mysql_fetch_field($result))
		{
			if ($i == 0) $xml_output .= "  <Table name='".$column->table."'>\n";
			$xml_output .= "    <Column name='".$column->name."' type='".convertMySqlType($column->type)."' />\n";
			$i++;
		}
		$xml_output .= "  </Table>\n";
		$xml_output .= "</Tables>";

		mysql_free_result($result);
		mysql_close($link);

		return $xml_output;
	}

	function getDataFromMySqlDatabase($host, $port, $database, $userId, $password, $query)
	{
		$link = mysql_connect($host.":".$port, $userId, $password) or die("ServerError:Could not connect to host.");
		mysql_select_db($database, $link) or die("ServerError:Could not find database.");

		$result = mysql_query($query, $link) or die("ServerError:Data not found.");

		$xml_output = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
		$xml_output .= "<Database>\n";

		$i = 0;
		while ($column = mysql_fetch_field($result))
		{
			$columns[$i] = $column->name;
			$tablename = $column->table;
			$i++;
		}

		while ($row = mysql_fetch_assoc($result))
		{
			$xml_output .= "  <".$tablename.">\n";
			foreach($columns as $column)
			{
				$value = $row[$column];
				$value = str_replace("&", "&amp;", $value);
				$value = str_replace("<", "&lt;", $value);
				$value = str_replace(">", "&gt;", $value);

				$xml_output .= "    <".$column.">".$value."</".$column.">\n";
			}
			$xml_output .= "  </".$tablename.">\n";
		}

		mysql_free_result($result);
		mysql_close($link);

		$xml_output .= "</Database>\n";
		return $xml_output;
	}

//--------------------------------------
//  ODBC Database
//--------------------------------------

	function parseOdbcConnectionString($connectionString)
	{
		class connectionInfo {
			var $dsn;
			var $userId;
			var $password;
		}

		$object = new connectionInfo;
		$object->dsn = "";
		$parameters = split(";", $connectionString);
		foreach($parameters as $parameter)
		{
			$parts = split("=", $parameter);
			$name = $parts[0];
			$value = $parts[1];

			if (isset($value))
			{
				switch (strtolower($name))
				{
					case "uid":
					case "user id":
					case "user":
						$object->userId = $value;
						break;

					case "pwd":
					case "password":
						$object->password = $value;
						break;
						
					default:
						if ($object->dsn != "") $object->dsn .= ";";
						$object->dsn .= $parameter;
						break;
				}
			}
		}

		return $object;
	}
	
	function convertOdbcType($type)
	{
		switch (strtolower($type))
		{
			case "varchar":
			case "longchar":
				return "System.String";

			case "counter":
			case "integer":
			case "byte":
				return "System.Int32";

			case "currency":
			case "double":
				return "System.Decimal";
				
			case "bit":
				return "System.Boolean";
				
			case "longbinary":
				return "System.Byte[]";

			case "datetime":
				return "System.DateTime";
		}

		return $type;
	}
	
	function getOdbcDatabaseColumns($dsn, $userId, $password, $query)
	{
		$link = odbc_connect($dsn, $userId, $password) or die("ServerError:Could not connect to host.");
		$result = odbc_exec($link, $query) or die("ServerError:Data not found.");
		
		odbc_fetch_row($result);
		$num = odbc_num_fields($result);
		
		$xml_output = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
		$xml_output .= "<Tables>\n";
		$xml_output .= "  <Table name='TableName'>\n";

		for($i = 1; $i <= $num; $i++)
		{
			$xml_output .= "    <Column name='".odbc_field_name($result, $i)."' type='".convertOdbcType(odbc_field_type($result, $i))."' />\n";
		}
		
		$xml_output .= "  </Table>\n";
		$xml_output .= "</Tables>";

		odbc_free_result($result);
		odbc_close($link);

		return $xml_output;
	}
	
	function getDataFromOdbcDatabase($dsn, $userId, $password, $query)
	{
		$link = odbc_connect($dsn, $userId, $password) or die("ServerError:Could not connect to host.");
		$result = odbc_exec($link, $query) or die("ServerError:Data not found.");

		$xml_output = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
		$xml_output .= "<Database>\n";

		odbc_fetch_row($result, 0);
		$num = odbc_num_fields($result);
		
		for($i = 1; $i <= $num; $i++)
		{
			$columns[$i] = odbc_field_name($result, $i);
		}
		
		while (odbc_fetch_row($result))
		{
			$xml_output .= "  <TableName>\n";
			for($i = 1; $i <= $num; $i++)
			{
				$type = convertOdbcType(odbc_field_type($result, $i));
				$column = $columns[$i];
				$value = odbc_result($result, $column);
				
				if ($type == "System.Byte[]") $value = base64_encode($value);
				else
				{
					$value = str_replace("&", "&amp;", $value);
					$value = str_replace("<", "&lt;", $value);
					$value = str_replace(">", "&gt;", $value);
				}
					
				$xml_output .= "    <".$column.">".$value."</".$column.">\n";
			}
			$xml_output .= "  </TableName>\n";
		}

		odbc_free_result($result);
		odbc_close($link);

		$xml_output .= "</Database>\n";
		
		return $xml_output;
	}
?>